Learn R Programming

svenssonm (version 0.1.0)

con_ta: Contingency Table Generation

Description

Generate Contingency table for Svensson's Method

Usage

con_ta(x, y, level = 5)

Arguments

x

a numeric vector of data values, each element range from 1 to level.

y

a numeric vector of data values, must have same length as x.

level

the dimension of the contingency table, the default is 5.

Value

A contingency table based on x and y.

See Also

sresult for summary of Svensson's method analysis.

Examples

Run this code
# NOT RUN {
x <- c (1:5,5:1)
y <- c(1:5,1,1,5,4,1)
con_ta(x,y,)
# }

Run the code above in your browser using DataLab