powered by
Generate Contingency table for Svensson's Method
con_ta(x, y, level = 5)
a numeric vector of data values, each element range from 1 to level.
a numeric vector of data values, must have same length as x.
the dimension of the contingency table, the default is 5.
A contingency table based on x and y.
x
y
sresult for summary of Svensson's method analysis.
sresult
# NOT RUN { x <- c (1:5,5:1) y <- c(1:5,1,1,5,4,1) con_ta(x,y,) # }
Run the code above in your browser using DataLab