In Svensson's method, the individual change is described by the relative rank variance (RV),
the observable part, and the internal rank variance (IV), the unobservable part, together.
A measure of the closeness of observations to the rank transformable pattern of change is
defined as the augmented correlation coefficient (ralpha) and its p-value.
Usage
rv(t)
rvse(t)
iv(t)
ralpha(t)
pralpha(t)
Arguments
t
The contingency table for Svensson's method, a two-dimension matrix.
Value
rv and iv give the RV and IV value. rvse gives the standard
error of RV. ralpha and pralpha give the augmented correlation coefficient
and the corresponding p-value.
See Also
con_ta for generating contingency table. syschange
for systematic change. sresult for summary of Svensson's method analysis.